@@ -1,5 +1,5 @@
 use super::{ClipboardResult, SelectionProvider};
-use crate::api::EventHub;
+use crate::api::{ClipboardProviding, EventHub};
 use std::sync::Arc;
 
 pub struct Clipboard {}
@@ -8,8 +8,6 @@ impl Clipboard {
   pub fn new<T>(
     _display_name: &str,
     _selection_provider: T,
-    _store_name: String,
-    _secret_id: String,
     _event_hub: Arc<dyn EventHub>,
   ) -> ClipboardResult<Clipboard>
   where
@@ -22,7 +20,7 @@ impl Clipboard {
     unimplemented!()
   }
 
-  pub fn currently_providing(&self) -> Option<String> {
+  pub fn currently_providing(&self) -> Option<ClipboardProviding> {
     unimplemented!()
   }
 
